Jing Ji 094c3ef60b OomAdjust Performance Improvement
* Reduce the number of processes to be computed.
* Reduce the overhead of getting process attributes

Overall by average the time spent on the OomAdjust update goes
down from 911us to 441us (51.6% faster) in Day-Of-Use test.

Bug: 135941673
Test: forrest test health/reliability/greenday
Test: Loop test
Test: atest MockingOomAdjusterTests
Test: atest FrameworksServicesTests:ActivityManagerServiceTest
Test: atest CtsAppTestCases:ActivityManagerProcessStateTest

Change-Id: I43cc4af4a268b24620c3231a87f7c9d2a14e4fbc
2019-10-17 10:57:35 -07:00
…
…
2019-10-14 02:51:06 +00:00
2019-08-26 14:23:52 -07:00
…
…
…
2019-10-11 16:10:48 -07:00
2019-08-09 09:24:40 -07:00
2019-10-10 22:41:57 +00:00
…
2019-07-24 15:54:24 +09:00
Description
No description provided
21 GiB
Languages
Java 73.7%
Kotlin 14%
PowerBuilder 5.8%
C++ 5.2%
AIDL 1%